@@ -62,3 +62,6 @@ class Image(BaseAPI):
 
     def __str__(self):
         return "%s %s %s" % (self.id, self.name, self.distribution)
+
+    def __repr__(self):
+        return "< %s %s %s >" % (self.id, self.distribution, self.name)
